==> pandoc-crossref-0.3.4.1-58-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.1
id: pandoc-crossref-0.3.4.1-3kyW90g7YntBpVSVhUiJW5
key: pandoc-crossref-0.3.4.1-3kyW90g7YntBpVSVhUiJW5
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: b6f935e72beacb575693d244577febb3
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-crossref-0.3.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-crossref-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.1-3kyW90g7YntBpVSVhUiJW5
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.3-BAweBxK5uZwLvRTyFUDuYE
    data-accessor-template-0.2.1.16-8Ng0MfMe48I5wN3yNUjjcp
    data-accessor-transformers-0.2.1.7-3bix1T9lHQfGW2Mkch4MmE
    data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.3-IUsR2ap7RpY7W979iFcy2L
    pandoc-types-1.17.5.4-D7d01VgN5zh3H111Wsm9XO
    roman-numerals-0.5.1.5-FuJ7WDlQ3j5dPU6y8xt1N
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.4.1-63-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.3.4.1
id: pandoc-crossref-0.3.4.1-HYaZ1cdh2YqEyM9KuaEmYJ
key: pandoc-crossref-0.3.4.1-HYaZ1cdh2YqEyM9KuaEmYJ
license: GPL-2.0-only
maintainer: root@livid.pp.ru
author: Nikolay Yakimov
homepage: https://github.com/lierdakil/pandoc-crossref#readme
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
abi: 985f674d19338395f79064ef8719d5aa
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Settings
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Paths_pandoc_crossref
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-crossref-0.3.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-crossref-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.3.4.1-HYaZ1cdh2YqEyM9KuaEmYJ
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-accessor-0.2.3-BAweBxK5uZwLvRTyFUDuYE
    data-accessor-template-0.2.1.16-8Ng0MfMe48I5wN3yNUjjcp
    data-accessor-transformers-0.2.1.7-3bix1T9lHQfGW2Mkch4MmE
    data-default-0.7.1.1-5ccnbkthejE9lCjbHMgc6 directory-1.3.3.0
    filepath-1.4.2.1 mtl-2.2.2 pandoc-2.7.3-1iLWpjOkipwj735Va2t6D
    pandoc-types-1.17.5.4-EPhCf6cGD3s5yOdhyVusUT
    roman-numerals-0.5.1.5-FuJ7WDlQ3j5dPU6y8xt1N
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW template-haskell-2.14.0.0
    text-1.2.3.1 utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
